@@ -2,4 +2,10 @@ from .activation import Activation
 from .condition import Condition, HyperrectangleCondition, DuplicatedFeatures
 from .rule import Rule, RegressionRule, ClassificationRule
 from .ruleset import RuleSet
+from .thresholds import Thresholds
 from .utils.rule_utils import extract_rules_from_tree
+
+try:
+    from ._version import __version__
+except ImportError:
+    pass
